@@ -1,7 +1,8 @@
-VERSION = (3, 1, 0)
+__version__ = "3.2.1"
 
+from .connection_utils import get_connection
 from .decorators import job
-from .queues import enqueue, get_connection, get_queue, get_scheduler
+from .queues import enqueue, get_queue, get_scheduler
 from .workers import get_worker
 
 __all__ = [
